@@ -1,7 +1,7 @@
 package Bencher::Scenario::PERLANCAR::require;
 
 our $DATE = '2016-01-21'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,6 +9,36 @@ use warnings;
 
 our $scenario = {
     summary => 'Benchmark require() in a tight loop/subroutine',
+    description => <<'_',
+
+`require()` can be put inside a block (like a subroutine) to delay loading a
+module:
+
+    sub foo {
+        require Some::Module;
+        ...
+    }
+
+After a module is loaded, the next `require()` should be cheap enough: it just
+checks against `%INC` to see if an entry for the module is there. So it should
+just be the cost of a single hash lookup.
+
+However, for very tight loops/subroutines, you can avoid (reduce) this cost by
+putting the `require()` inside a state variable, which will cause the
+`require()` to be evaluated just once:
+
+    sub foo {
+        state $dummy = do { require Some::Module };
+        ...
+    }
+
+There is a per-sub-invocation cost too of setting up the state variable
+`$dummy`. But this cost is several times smaller.
+
+Or, alternatively, you might also want to decide to put the `require()`
+statement outside of the block/subroutine.
+
+_
     participants => [
         {
             name=>'baseline_empty_sub',
@@ -18,6 +48,11 @@ our $scenario = {
             name=>'require_in_sub',
             code_template=>'require File::Find',
         },
+        {
+            name=>'require_in_sub_pm',
+            code_template=>'require "File/Find.pm"',
+            summary => 'There is no effect of using the path form',
+        },
         {
             name=>'require_in_state',
             code_template=>'state $dummy = do { require File::Find }',
@@ -40,7 +75,7 @@ Bencher::Scenario::PERLANCAR::require - Benchmark require() in a tight loop/subr
 
 =head1 VERSION
 
-This document describes version 0.01 of Bencher::Scenario::PERLANCAR::require (from Perl distribution Bencher-Scenarios-PERLANCAR), released on 2016-01-21.
+This document describes version 0.02 of Bencher::Scenario::PERLANCAR::require (from Perl distribution Bencher-Scenarios-PERLANCAR), released on 2016-01-21.
 
 =head1 SYNOPSIS
 
@@ -70,6 +105,16 @@ Code template:
 
 
 
+=item * require_in_sub_pm (perl_code)
+
+There is no effect of using the path form.
+
+Code template:
+
+ require "File/Find.pm"
+
+
+
 =item * require_in_state (perl_code)
 
 Code template:
@@ -86,16 +131,45 @@ Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (
 
 Benchmark with default options (C<< bencher -m PERLANCAR::require >>):
 
- +--------------------+------------+-----------+---------+---------+
- | participant        | rate (/s)  | time (ns) | errors  | samples |
- +--------------------+------------+-----------+---------+---------+
- | require_in_sub     | 1.4e+07    | 72        | 4.4e-10 | 23      |
- | require_in_state   | 1.3179e+08 | 7.58782   | 0       | 21      |
- | baseline_empty_sub | 1e+09      | 0.8       | 1.1e-10 | 20      |
- +--------------------+------------+-----------+---------+---------+
+ +--------------------+-------------+-----------+---------+---------+
+ | participant        | rate (/s)   | time (ns) | errors  | samples |
+ +--------------------+-------------+-----------+---------+---------+
+ | require_in_sub     | 1.4e+07     | 73        | 2.5e-10 | 20      |
+ | require_in_sub_pm  | 1.43e+07    | 70.1      | 5.2e-11 | 20      |
+ | require_in_state   | 1.27825e+08 | 7.82322   | 0       | 20      |
+ | baseline_empty_sub | 2e+09       | 0.6       | 5.5e-10 | 20      |
+ +--------------------+-------------+-----------+---------+---------+
 
 =head1 DESCRIPTION
 
+C<require()> can be put inside a block (like a subroutine) to delay loading a
+module:
+
+ sub foo {
+     require Some::Module;
+     ...
+ }
+
+After a module is loaded, the next C<require()> should be cheap enough: it just
+checks against C<%INC> to see if an entry for the module is there. So it should
+just be the cost of a single hash lookup.
+
+However, for very tight loops/subroutines, you can avoid (reduce) this cost by
+putting the C<require()> inside a state variable, which will cause the
+C<require()> to be evaluated just once:
+
+ sub foo {
+     state $dummy = do { require Some::Module };
+     ...
+ }
+
+There is a per-sub-invocation cost too of setting up the state variable
+C<$dummy>. But this cost is several times smaller.
+
+Or, alternatively, you might also want to decide to put the C<require()>
+statement outside of the block/subroutine.
+
+
 Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
 
 =head1 HOMEPAGE
